@@ -41,6 +41,16 @@ def md5sum(*, _file_path: str = None, _string: str = None):
     raise ValueError("参数_file_path与_string必须二选一，不能都为空")
 
 
+def md5_file(target):
+    """计算文件md5值"""
+    return md5sum(_file_path=target)
+
+
+def md5_str(target):
+    """计算字符串md5值"""
+    return md5sum(_string=target)
+
+
 class MyCrypto(object):
     @classmethod
     def encrypt(cls, data, xsrf_token=None, old_secret=None) -> str:
